#!/bin/bash
#
# Create CA Intermediate
# 
# 
# This function will generate a CA Intermediate
# IN: UNIQ_ID_CA, SERIAL
#

# source this file to include the functions
. cfg/pki_funcs.sh

PARAM1=$1
PARAM2=$2
PARAM3=$3


usage() {
  echo
  echo "Generate a new CA Intermediate certificate"
  echo
  echo "This program will generate a new certificate authority (CA) intermediate"
  echo "It requires a CA certificate used to sign CA Intermediate"
  echo "Requires the file \"ca.pem\" that is used to sign the certificates"
  echo 
  echo "  usage:   gen_ca-i.sh  <Org URL> <Serial>"
  echo
  echo "  example: gen_ca-i.sh  skunkworks.acme.xyz"
  echo "                        10052"
  echo
  exit 1
}

error_no_ca_file() {
  echo_block "ERROR: missing ca.crt.pem, ca.keys.pem"
  usage
}


main() {
  CDD=`pwd`
  FQ_CA_KEYS="${CDD}/cfg/ca.keys.pem"
  FQ_CA_CRT="${CDD}/cfg/ca.crt.pem"
  if [[ ! -f $FQ_CA_KEYS ]] || [[ ! -f $FQ_CA_CRT ]]; then
    error_no_ca_file
  fi

  if [[ -n $PARAM1 ]] && [[ -n $PARAM2 ]]; then
    pki_func_init $FQ_CA_CRT $FQ_CA_KEYS "${CDD}/cfg"

    if [[ -z $PARAM3 ]]; then
      PARAM3=5
    fi

    ca-i_gen_pki $PARAM1 $PARAM2 $PARAM3
  else
    usage
  fi
}

main
